package trip.model;

import java.util.Collection;
import java.util.Collections;
import java.util.HashSet;
import java.util.Set;
import java.util.TreeSet;

/**
 * Abstract Java component that is composed of other JavaComponents.
 *
 */
public abstract class JavaCompositeComponent extends JavaComponent {
	
	private Set<JavaComponent> children;
	
	public JavaCompositeComponent() {
		children = new HashSet<JavaComponent>();
	}
	
	@Override
	protected boolean removeChild(JavaComponent component) {
		return children.remove(component);
	}
	
	@Override
	public Collection<JavaComponent> getChildren() {
		return Collections.unmodifiableSet(children);
	}
	
	@Override
	protected boolean addChild(JavaComponent component) throws IllegalArgumentException {
		return children.add(component);
	}
}
