package trip.model;

public abstract class JavaMember extends JavaLeafComponent {
	
	private String name;
	private JavaType type;
	
	public JavaMember(String name, JavaType type) {
		this.name = name;
		this.type = type;
	}
	
	/**
	 * Sets the parent of this JavaMember and also sets this JavaMember as a child of the parameter
	 * object. JavaMembers can be parented by
	 * <ul><li>JavaType</li>
	 * <ul><li>JavaInterface</li>
	 *     <li>JavaClass</li>
 *     </ul></ul> 
	 * <p><b>Side Effects:</b> Calling this method results in this component adding itself 
	 * to the new parent's collection of children. If it can't successfully do this then
	 * the method returns false.</p>
	 * <p>If newParent is null then this component is removed from its current parent
	 * and becomes an orphaned component.</p>
	 * 
	 * @param newParent The new parent of this component. Null to orphan this component.
	 * @return True if the parent was changed, otherwise false.
	 */
	@Override
	public boolean setParent(JavaCompositeComponent newParent) {
		if (newParent == null ||
			newParent instanceof JavaType)
			return super.setParent(newParent);
		else throw new IllegalArgumentException
			("JavaMembers can only be the children of JavaTypes.");
	}
	
	public String getName() {
		return name;
	}
	
	public JavaType getType() {
		return type;
	}
}
