package trip.model;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;


public class JavaMethod extends JavaMember {

	private boolean constructor = false;
	private List<JavaParameter> parameters;
	
	public JavaMethod(String name, JavaType returnType) {
		super(name, returnType);
	}
	

	public boolean isConstructor() { return constructor; }
	public void setIsConstructor(boolean isConstructor) { 
		constructor = isConstructor; 
	}
	
	/**
	 * Gets an <b>unmodifiable</b> list of parameters.
	 * @return An unmodifiable list of this method's parameters.
	 */
	public List<JavaParameter> getParameters() {
		if (parameters == null) parameters = new ArrayList<JavaParameter>();
		return Collections.unmodifiableList(parameters);
	}
	
	public void setParameters(List<JavaParameter> params) {
		parameters = params;
	}
	
	/**
	 * Adds a new parameter to the end of this method's parameter list.
	 * @param param The parameter to append to the parameter list.
	 */
	public void addParameter(JavaParameter param) {
		if (parameters == null) parameters = new ArrayList<JavaParameter>();
		parameters.add(param);
	}
}
